Learn R Programming

bpAcc (version 0.0-2)

Supplementary functions: Supplementary fuctions of the package bpAcc.

Description

Supplementary function required to compute the acceptance probability of a device for BP measurement.

Usage

fsup1(mu, sd.aami, ptolerror)
  fsup2(mu.aami, sdev, ptolerror)
  toint(xbar, mean, sd, n)

Value

No value returned. These are funtcion internally called by ProbAccept.

Arguments

mu

True mean error (bias). This is 'mu' of the errors distribution (normal).

sd.aami

Standard deviation of a normal distribution meeting the ANSI/AAMI-SP10 standards.

ptolerror

Probability of tolerable error. Default is 0.85.

mu.aami

Mean of a normal distribution meeting the ANSI/AAMI-SP10 standards.

sdev

True standard deviation of the errors (normal distribution).

xbar, mean, sd, n

Auxiliary arguments.

Author

Tanvi Chandel, Tet-Chuan Lee, Andrew Lowe, Victor Miranda.

Details

Supplementary functions to compute the probability of accepting the device D. The errors (average of the differences from three device measurements and the three corresponding reference readings) are by default normally distributed with mean mean and sd. Function fsup1 is called by root, fsup2 is needed by rootinv, and toint is required by psigmaami.

See psigmaami for further details on ptolerror.

References

Chandel, T. and Lee, TC. and Lowe, A. and Miranda, V. (2022) Blood Pressure Device Accuracy Evaluation: Statistical Considerations with an Implementarion in R, Statistical Methods in Medical Research (under review).

See Also

ProbAccept psigmaami

Examples

Run this code
#### 'sd' that meets the AAMI-sp10 standars
root(mu = 5, ptolerror = 0.9)
# root(mu = 11, ptolerror = 0.85) # Error

#### 'mu' that meets the AAMI-sp10 standars
rootinv(sdev = 3, ptolerror = 0.9)
# rootinv(sdev = 2, ptolerror = 0.85) # Error

Run the code above in your browser using DataLab