Learn R Programming

bpAcc (version 0.0-2)

notDocumentedYetbpAcc: Not-documented functions and classes in bpAcc.

Description

Those functions not documented yet in bpAcc are aliased to this file.

Arguments

Value

Overall, these functions returns objects required by functions from bpAcc.

Further details will be given shortly.

Author

T. Chandel, V. Miranda, A. Lowe, T. Lee

Details

These functions are still under review or being tested, and will be documented over time.