powered by
Those functions not documented yet in bpAcc are aliased to this file.
Overall, these functions returns objects required by functions from bpAcc.
Further details will be given shortly.
T. Chandel, V. Miranda, A. Lowe, T. Lee
These functions are still under review or being tested, and will be documented over time.